% FORMULA DI SIMPSON PER IL CALCOLO APPROSSIMATO DI INTEGRALI
%
% function I = simpson(funz,a,b)
%
% DATI DI INPUT:
%  funz = stringa contenente il nome della funzione integranda
%         (definita in un omonimo file .m oppure inline)
%         
%     a = estremo inferiore dell'intervallo di integrazione
%     b = estremo superiore dell'intervallo di integrazione
%
% DATI DI OUTPUT:
%     I = approssimazione dell'integrale
%

function I = simpson(funz,a,b)

h = (b-a)/2;
fa = feval(funz,a);
fb = feval(funz,b);
fc = feval(funz,(a+b)/2);
I = (fa + fb + 4*fc) * h/3;

